Name:           libssh
Version:        0.6.0
Release:        1
Summary:        A library implementing the SSH2 protocol (0xbadc0de version)
Group:          System Environment/Libraries
License:        LGPLv2+
URL:            http://0xbadc0de.be/?part=libssh
Source0:        http://0xbadc0de.be/libssh/%{name}-%{version}.tar.bz2
Source1:        http://0xbadc0de.be/libssh/%{name}-%{version}.tar.asc
Patch0:         %{name}-%{version}-aix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:  cmake >= 2.8.12.2

BuildRequires:  krb5-devel >= 1.14.4-1
BuildRequires:  openssl-devel >= 1.0.2j-2
BuildRequires:  zlib-devel >= 1.2.3-7
Requires:       krb5-libs >= 1.14.4-1
Requires:       openssl >= 1.0.2j-2
Requires:       zlib >= 1.2.3-7

%description
The ssh library was designed to be used by programmers needing a
working SSH implementation by the mean of a library. The complete
control of the client is made by the programmer. With libssh, you can
remotely execute programs, transfer files, use a secure and transparent
tunnel for your remote programs. With its Secure FTP implementation,
you can play with remote files easily, without third-party programs
others than libcrypto (from openssl).

Features:
- Full C library functions for manipulating a client-side SSH connection
- Fully configurable sessions
- Support for AES-128,AES-192,AES-256,blowfish, in cbc mode
- Use multiple SSH connections in a same process, at same time
- Usable SFTP implementation
- Public key and password authentication


%package devel
Summary:         Development files for %{name}
Group:           Development/Libraries
Requires:        %{name} = %{version}-%{release}
Requires:        krb5-devel >= 1.14.4-1
Requires:        openssl-devel >= 1.0.2j-2
Requires:        zlib-devel >= 1.2.3-7

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q
%patch0


%build
export CC="xlc_r"
export CXX="xlC_r"

mkdir -p build
cd build

cmake \
-DCMAKE_INSTALL_PREFIX=%{_prefix} \
-DCMAKE_BUILD_TYPE=Release \
-DWITH_STATIC_LIB=ON \
..

# first build 64-bit static libraries
export OBJECT_MODE=64
gmake ssh_static ssh_threads_static # doesn't build with %{?_smp_mflags}

CreateExportList -X64 %{name}.exp src/%{name}.a
${CC} -q64 -qmkshrobj src/%{name}.a -o shr64.o -bE:%{name}.exp -L/opt/freeware/lib -lgssapi_krb5 -lssl -lcrypto -lz
rm -f %{name}.exp

CreateExportList -X64 %{name}.exp src/threads/%{name}_threads.a
${CC} -q64 -qmkshrobj src/threads/%{name}_threads.a -o src/shr64.o -bE:%{name}.exp -L/opt/freeware/lib -lgssapi_krb5 -lssl -lcrypto -lz
rm -f %{name}.exp

gmake clean

# now build the 32-bit static libraries
export OBJECT_MODE=32
gmake ssh_static ssh_threads_static # doesn't build with %{?_smp_mflags}

CreateExportList -X32 %{name}.exp src/%{name}.a
${CC} -q32 -qmkshrobj src/%{name}.a -o shr.o -bE:%{name}.exp -L/opt/freeware/lib -lgssapi_krb5 -lssl -lcrypto -lz
rm -f %{name}.exp

CreateExportList -X32 %{name}.exp src/threads/%{name}_threads.a
${CC} -q32 -qmkshrobj src/threads/%{name}_threads.a -o src/shr.o -bE:%{name}.exp -L/opt/freeware/lib -lgssapi_krb5 -lssl -lcrypto -lz
rm -f %{name}.exp

# now create the AIX-style shared libraries
/usr/bin/ar -X32 -rv %{name}.a shr.o
/usr/bin/ar -X64 -q  %{name}.a shr64.o

/usr/bin/ar -X32 -rv %{name}_threads.a src/shr.o
/usr/bin/ar -X64 -q  %{name}_threads.a src/shr64.o


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}%{_libdir}
mkdir -p ${RPM_BUILD_ROOT}%{_includedir}/%{name}

cd build

cp %{name}.a ${RPM_BUILD_ROOT}%{_libdir}/%{name}.a
cp %{name}_threads.a ${RPM_BUILD_ROOT}%{_libdir}/%{name}_threads.a
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/*

for f in callbacks.h legacy.h libssh.h libsshpp.hpp server.h sftp.h ssh2.h ; do
    cp ../include/%{name}/${f} ${RPM_BUILD_ROOT}%{_includedir}/%{name}/
done
chmod 0644 ${RPM_BUILD_ROOT}%{_includedir}/%{name}/*

# pkgconfig stuff
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
chmod 0755 ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
cp *.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/*

# cmake stuff
mkdir -p ${RPM_BUILD_ROOT}%{_libdir}/cmake/%{name}
chmod 0755 ${RPM_BUILD_ROOT}%{_libdir}/cmake/%{name}
cp libssh-config-version.cmake ${RPM_BUILD_ROOT}%{_libdir}/cmake/%{name}/
cat libssh-config.cmake | \
    sed 's|LIBSSH_THREADS_LIBRARY /opt/freeware/lib/libssh.so|LIBSSH_THREADS_LIBRARY /opt/freeware/lib/libssh_threads.a|g' | \
    sed 's|/opt/freeware/lib/libssh.so|/opt/freeware/lib/libssh.a|g' \
    > ${RPM_BUILD_ROOT}%{_libdir}/cmake/%{name}/libssh-config.cmake
chmod 0644 ${RPM_BUILD_ROOT}%{_libdir}/cmake/%{name}/*

(
  cd ${RPM_BUILD_ROOT}
  for dir in include lib
  do
    mkdir -p usr/$dir
    cd usr/$dir
    ln -sf ../..%{_prefix}/$dir/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc AUTHORS ChangeLog COPYING INSTALL README
%{_libdir}/*.a
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%{_includedir}/*
%{_libdir}/pkgconfig/*
%dir  %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/libssh-config.cmake
%{_libdir}/cmake/%{name}/libssh-config-version.cmake
/usr/include/*


%changelog
* Fri Dec 02 2016 Michael Perzl <michael@perzl.org> - 0.6.0-1
- updated to version 0.6.0

* Wed Nov 16 2016 Michael Perzl <michael@perzl.org> - 0.5.5-2
- added missing shared libraries and include files
- recompiled against latest versions

* Fri Aug 02 2013 Michael Perzl <michael@perzl.org> - 0.5.5-1
- updated to version 0.5.5

* Tue Jan 29 2013 Michael Perzl <michael@perzl.org> - 0.5.4-1
- updated to version 0.5.4

* Thu Dec 13 2012 Michael Perzl <michael@perzl.org> - 0.5.3-1
- updated to version 0.5.3

* Tue Sep 20 2011 Michael Perzl <michael@perzl.org> - 0.5.2-1
- updated to version 0.5.2

* Sun Sep 18 2011 Michael Perzl <michael@perzl.org> - 0.5.1-1
- updated to version 0.5.1

* Wed Jun 01 2011 Michael Perzl <michael@perzl.org> - 0.5.0-1
- updated to version 0.5.0

* Fri Jan 21 2011 Michael Perzl <michael@perzl.org> - 0.4.8-1
- updated to version 0.4.8

* Thu Dec 30 2010 Michael Perzl <michael@perzl.org> - 0.4.7-1
- updated to version 0.4.7

* Mon Sep 06 2010 Michael Perzl <michael@perzl.org> - 0.4.6-1
- updated to version 0.4.6

* Tue Jul 13 2010 Michael Perzl <michael@perzl.org> - 0.4.5-1
- updated to version 0.4.5

* Tue Jul 13 2010 Michael Perzl <michael@perzl.org> - 0.4.4-1
- first version for AIX V5.1 and higher
